@@ -95,10 +95,10 @@
 #' terms of their mutual distances. Psychometrika, 3(1):19-22, 1938.
 #'
 #' @examples
-#' data(examples)
-#' mds(examples$DZ,nnlines=TRUE,pch=21,cex=5)
+#' attach(examples)
+#' mds(DZ,nnlines=TRUE,pch=21,cex=5)
 #' dev.new()
-#' mds(examples$DZ,shepard=TRUE)
+#' mds(DZ,shepard=TRUE)
 #' @rdname mds
 #' @export
 mds <- function(x,...){ UseMethod("mds",x) }
@@ -106,7 +106,7 @@ mds <- function(x,...){ UseMethod("mds",x) }
 #' @export
 mds.default <- function(x,classical=FALSE,plot=TRUE,shepard=FALSE,
                         nnlines=FALSE,pos=NULL,col='black',
-                        bg='white',xlab="",ylab="",...){
+                        bg='white',xlab=NA,ylab=NA,...){
     out <- list()
     if (classical) out$points <- stats::cmdscale(x)
     else out <- MASS::isoMDS(d=x)
@@ -122,7 +122,7 @@ mds.default <- function(x,classical=FALSE,plot=TRUE,shepard=FALSE,
 #' @export
 mds.detritals <- function(x,classical=FALSE,plot=TRUE,shepard=FALSE,
                           nnlines=FALSE,pos=NULL,col='black',
-                          bg='white',xlab="",ylab="",hide=NULL,...){
+                          bg='white',xlab=NA,ylab=NA,hide=NULL,...){
     if (is.character(hide)) hide <- which(names(x)%in%hide)
     x2plot <- clear(x,hide)
     d <- diss(x2plot)
@@ -159,13 +159,12 @@ KS.diss <- function(x,y) {
     return(out)
 }
 
-# arguments:
 plot.MDS <- function(x,nnlines=FALSE,pos=NULL,shepard=FALSE,
-                     col='black',bg='white',xlab,ylab,pch,...){
+                     col='black',bg='white',xlab=NA,ylab=NA,pch,...){
     if (shepard & !x$classical){
         if (missing(pch)) pch <- 21
-        if (missing(xlab)) xlab <- 'dissimilarities'
-        if (missing(ylab)) ylab <- 'distances/disparities'
+        if (is.na(xlab)) xlab <- 'dissimilarities'
+        if (is.na(ylab)) ylab <- 'distances/disparities'
         shep <- MASS::Shepard(x$diss,x$points)
         graphics::plot(x=shep,col=col,bg=bg,pch=pch,
                        xlab=xlab,ylab=ylab,...)
